{ lib, pkgs, config,  ... }:
let
    adminer = pkgs.callPackage ../commons/adminer.nix {};
    cfg = config.myServices.websites.florian.integration;
    varDir = "/var/lib/ftp/florian";
    env = config.myEnv.websites.florian;
in {
  options.myServices.websites.florian.integration.enable = lib.mkEnableOption "enable Florian's website integration";

  config = lib.mkIf cfg.enable {
    security.acme2.certs."ftp".extraDomains."florian.immae.eu" = null;

    services.websites.env.integration.modules = adminer.apache.modules;
    services.websites.env.integration.vhostConfs.florian = {
      certName    = "integration";
      addToCerts  = true;
      hosts       = [ "florian.immae.eu" ];
      root        = "${varDir}/florian.immae.eu";
      extraConfig = [
        adminer.apache.vhostConf
        ''
        ServerAdmin ${env.server_admin}

        <Directory ${varDir}/florian.immae.eu>
          DirectoryIndex index.php index.htm index.html
          Options Indexes FollowSymLinks MultiViews Includes
          AllowOverride None
          Require all granted
        </Directory>
          ''
      ];
    };
  };
}
